==> gatsby-sports-theme-1.0.7.tgz: package/src/gatsby-core-theme/components/molecules/toplist/default-row/index.js <==
/* eslint-disable react/prop-types */
/* eslint-disable import/no-extraneous-dependencies */
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import Bonus from '~atoms/bonus';
import { Context } from '~context/MainProvider';
import SellingPoints from '~atoms/selling-points';
import StarRating from '~molecules/star-rating/one-star';
import Link from '~hooks/link';
import OperatorCta from '~atoms/operator-cta';
import { prettyTracker, imagePrettyUrl, translate, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';

import styles from './default-row.module.scss';

const Row = ({
  item,
  oneliner = 'main',
  layout = 'list',
  tracker = 'main',
  pageTemplate,
  itemRefs,
  index,
  className,
}) => {
  const prettyLink = prettyTracker(item, 'main', false, pageTemplate);
  const itemRating = item.rating;
  const { translations } = useContext(Context) || {};
  const reviewPath = item.review_link ? `/${item.review_link}` : item.path || '/';
  const imageObject = item?.standardised_logo_url_object || item?.logo_url_object;

  const addToRefs = (el, itemNum) => {
    if (el && itemRefs) {
      itemRefs.current[itemNum] = el;
    }
  };

  return (
    <li
      className={`${className} ${styles.row} ${styles[layout]}`}
      ref={(el) => addToRefs(el, index)}
    >
      <div className={styles.ribbons}>
        {item.ribbons && item.ribbons.map((ribbon) => <span>{ribbon}</span>)}
      </div>
      <div className={styles.logo}>
        <a
          href={prettyLink}
          title={item.name}
          className="casinos-top-list-gtm logo-cta"
          target="_blank"
          rel="noreferrer"
          aria-label={`${item.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, item.name)}
            src={imagePrettyUrl(imageObject?.filename || item?.logo_url, 96, 96)}
            width={96}
            height={96}
          />
        </a>
        <div>
          <p>{item.name}</p>
          <StarRating numOfStars={5} rating={itemRating} />
          <Link className={`${styles.reviewLink} toplist-variant-one-gtm`} to={reviewPath}>
            {`${translate(translations, 'read_review', 'Review')}`}
          </Link>
        </div>
      </div>
      <SellingPoints sellingPoints={item.selling_points} />
      <a
        href={prettyLink}
        target="_blank"
        rel="noreferrer"
        className={`toplist-variant-one-gtm bonus-cta ${styles.oneliner}`}
      >
        <Bonus item={item} tracker={oneliner} />
      </a>
      <OperatorCta
        operator={item}
        tracker={tracker}
        gtmClass="toplist-operator-cta-gtm"
        pageTemplate={pageTemplate}
      />
    </li>
  );
};

Row.propTypes = {
  oneliner: PropTypes.string,
  layout: PropTypes.string,
  tracker: PropTypes.string,
  item: PropTypes.shape({
    name: PropTypes.string,
    ribbons: PropTypes.arrayOf(PropTypes.string),
    logo_url: PropTypes.string,
    selling_points: PropTypes.arrayOf(PropTypes.string),
    review_link: PropTypes.string,
    rating: PropTypes.string,
    one_liners: PropTypes.shape({
      main: PropTypes.shape({
        one_liner: PropTypes.string,
      }),
    }),
    logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    standardised_logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    bonus: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
  }).isRequired,
  pageTemplate: PropTypes.string,
};

export default Row;

==> gatsby-sports-theme-1.0.10.tgz: package/src/gatsby-core-theme/components/molecules/toplist/default-row/index.js <==
/* eslint-disable react/prop-types */
/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import PropTypes from 'prop-types';
import ReviewLink from 'gatsby-core-theme/src/components/atoms/review-link';
import Bonus from '~molecules/bonus-box/template-one';
import SellingPoints from '~atoms/selling-points';
import StarRating from '~molecules/star-rating/one-star';
import OperatorCta from '~atoms/button/operator-cta';
import { prettyTracker, imagePrettyUrl, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';

import styles from './default-row.module.scss';

const Row = ({
  item,
  oneliner = 'main',
  layout = 'list',
  tracker = 'main',
  pageTemplate,
  itemRefs,
  index,
  className,
}) => {
  const prettyLink = prettyTracker(item, 'main', false, pageTemplate);
  const itemRating = item.rating;
  const reviewPath = item.review_link ? `${item.review_link}` : item.path || '/';
  const imageObject = item?.standardised_logo_url_object || item?.logo_url_object;

  const addToRefs = (el, itemNum) => {
    if (el && itemRefs) {
      itemRefs.current[itemNum] = el;
    }
  };

  return (
    <li
      className={`${className} ${styles.row} ${styles[layout]}`}
      ref={(el) => addToRefs(el, index)}
    >
      <div className={styles.ribbons}>
        {item.ribbons && item.ribbons.map((ribbon) => <span>{ribbon}</span>)}
      </div>
      <div className={styles.logo}>
        <a
          href={prettyLink}
          title={item.name}
          className="casinos-top-list-gtm logo-cta"
          target="_blank"
          rel="noreferrer"
          aria-label={`${item.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, item.name)}
            src={imagePrettyUrl(imageObject?.filename || item?.logo_url, 96, 96)}
            width={96}
            height={96}
          />
        </a>
        <div>
          <p>{item.name}</p>
          <StarRating numOfStars={5} rating={itemRating} />
          <ReviewLink reviewPath={reviewPath} operatorName={item?.name} />
        </div>
      </div>
      <SellingPoints sellingPoints={item.selling_points} />
      <Bonus item={item} tracker={oneliner} />
      <OperatorCta
        operator={item}
        tracker={tracker}
        gtmClass="toplist-operator-cta-gtm"
        pageTemplate={pageTemplate}
      />
    </li>
  );
};

Row.propTypes = {
  oneliner: PropTypes.string,
  layout: PropTypes.string,
  tracker: PropTypes.string,
  item: PropTypes.shape({
    name: PropTypes.string,
    ribbons: PropTypes.arrayOf(PropTypes.string),
    logo_url: PropTypes.string,
    selling_points: PropTypes.arrayOf(PropTypes.string),
    review_link: PropTypes.string,
    rating: PropTypes.string,
    one_liners: PropTypes.shape({
      main: PropTypes.shape({
        one_liner: PropTypes.string,
      }),
    }),
    logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    standardised_logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    bonus: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
  }).isRequired,
  pageTemplate: PropTypes.string,
};

export default Row;
